==> ui-framework-elements-4.3.14.jar: gen/displays/templates/AbstractWidgetSummaryMold.js <==
import React from "react";
import UiBlock from "alexandria-ui-elements/src/displays/components/Block";
import UiOpenPage from "alexandria-ui-elements/src/displays/components/OpenPage";
import UiText from "alexandria-ui-elements/src/displays/components/Text";
import UiMultiple from "alexandria-ui-elements/src/displays/components/Multiple";
import UiTemplate from "alexandria-ui-elements/src/displays/components/Template";
import Notifier from "../notifiers/Notifier";
import Requester from "../requesters/Requester";

export default class AbstractWidgetSummaryMold extends UiTemplate {

	constructor(props) {
		super(props);
	};

	render() {
	    const display = !this.state.visible ? {display:'none'} : undefined;
		return(
			<UiBlock layout="vertical flexible" width="100.0%" height="100.0%" style={{...this.props.style,...display}}>
				<UiBlock context={this._context.bind(this)} owner={this._owner.bind(this)} id="a1760563619" layout="vertical flexible" width="400px" height="-1px" paper>
					<UiOpenPage context={this._context.bind(this)} owner={this._owner.bind(this)} id="a_1507377868" title="" target="self" mode="Link" size="Large" format="h6">
					</UiOpenPage>
					<UiBlock context={this._context.bind(this)} owner={this._owner.bind(this)} id="a1819807205" layout="flexible">
						<UiText context={this._context.bind(this)} owner={this._owner.bind(this)} id="a2023875803" mode="normal">
						</UiText>
					</UiBlock>
					<UiMultiple context={this._context.bind(this)} owner={this._owner.bind(this)} id="a107217472" format="body2" multiple={{instances:"facets",arrangement:"Horizontal",noItemsMessage:"",spacing:0,wrap:true}} mode="normal" highlighted={{text:"white",background:"#679164"}}>
					</UiMultiple>
				</UiBlock>
			</UiBlock>
		);
	}
}

==> ui-framework-elements-4.3.21.jar: gen/displays/templates/AbstractWidgetSummaryMold.js <==
import React from "react";
import UiBlock from "alexandria-ui-elements/src/displays/components/Block";
import UiOpenPage from "alexandria-ui-elements/src/displays/components/OpenPage";
import UiText from "alexandria-ui-elements/src/displays/components/Text";
import UiMultiple from "alexandria-ui-elements/src/displays/components/Multiple";
import UiTemplate from "alexandria-ui-elements/src/displays/components/Template";
import Notifier from "../notifiers/Notifier";
import Requester from "../requesters/Requester";

export default class AbstractWidgetSummaryMold extends UiTemplate {

	constructor(props) {
		super(props);
	};

	render() {
	    const display = !this.state.visible ? {display:'none'} : undefined;
	    const className = "layout vertical center-justified" + (this.hiddenClass() !== "" ? " " + this.hiddenClass() : "");
		return(
			<UiBlock layout="vertical flexible" width="100.0%" height="100.0%" style={{...this.props.style,...display}}>
				<UiBlock context={this._context.bind(this)} owner={this._owner.bind(this)} id="a843766165" layout="vertical flexible" width="400px" height="-1px" paper>
					<UiOpenPage context={this._context.bind(this)} owner={this._owner.bind(this)} id="a_1507377868" title="" target="self" mode="Link" size="Large" format="h6">
					</UiOpenPage>
					<UiBlock context={this._context.bind(this)} owner={this._owner.bind(this)} id="a1819807205" layout="flexible">
						<UiText context={this._context.bind(this)} owner={this._owner.bind(this)} id="a2023875803" mode="normal">
						</UiText>
					</UiBlock>
					<UiMultiple context={this._context.bind(this)} owner={this._owner.bind(this)} id="a107217472" format="body2" multiple={{instances:"facets",arrangement:"Horizontal",noItemsMessage:"",spacing:0,editable:false,wrap:true,count:{min:0,max:-1}}} mode="normal" highlighted={{text:"white",background:"#679164"}}>
					</UiMultiple>
				</UiBlock>
			</UiBlock>
		);
	}
}
